Validation
==========

Functions for validating data before creating parameters.

Exception
---------

.. autoexception:: cvxpy_or.ValidationError
   :members:
   :show-inheritance:

Validation Functions
--------------------

.. autofunction:: cvxpy_or.validate_keys

.. autofunction:: cvxpy_or.validate_numeric

.. autofunction:: cvxpy_or.validate_bounds

.. autofunction:: cvxpy_or.validate_parameter
